emacs-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: Missing changes in merges from emacs-25 to master


From: Óscar Fuentes
Subject: Re: Missing changes in merges from emacs-25 to master
Date: Tue, 22 Mar 2016 16:20:50 +0100
User-agent: Gnus/5.13 (Gnus v5.13) Emacs/25.0.92 (gnu/linux)

martin rudalics <address@hidden> writes:

>> git diff 9304e6d3a222de6ef1c405bfd6e09eee6ed2c2aa^2  
>> 9304e6d3a222de6ef1c405bfd6e09eee6ed2c2aa -- src/window.c
>
> With git version 1.9.4.msysgit.2 (on Windows) this gets me
>
> git diff 9304e6d3a222de6ef1c405bfd6e09eee6ed2c2aa^2 
> 9304e6d3a222de6ef1c405bfd6e09eee6ed2c2aa -- src/window.c
> fatal: bad revision '9304e6d3a222de6ef1c405bfd6e09eee6ed2c2aa2'

Most probably that git version is too old to support the ^2 syntax.
Please install the latest Git for Windows:

https://git-for-windows.github.io/

The output is

diff --git a/src/window.c b/src/window.c
index 9e065ea..70b7e58 100644
--- a/src/window.c
+++ b/src/window.c
@@ -3971,11 +3971,9 @@ values.  */)
 }
 
 
-/* Resize frame F's windows when F's width or height is set to SIZE.
-   If HORFLAG is zero, F's width was set to SIZE, otherwise its height
-   was set.  SIZE is interpreted in F's canonical character units
-   (a.k.a. "columns" or "lines"), unless PIXELWISE is non-zero, which
-   means to interpret SIZE in pixel units.  */
+/* Resize frame F's windows when number of lines of F is set to SIZE.
+   HORFLAG means resize windows when number of columns of F is set to
+   SIZE.  PIXELWISE means to interpret SIZE as pixels.  */
 void
 resize_frame_windows (struct frame *f, int size, bool horflag, bool pixelwise)
 {
@@ -4076,7 +4074,7 @@ resize_frame_windows (struct frame *f, int size, bool 
horflag, bool pixelwise)
       m = XWINDOW (mini);
       if (horflag)
        {
-         m->total_cols = new_size;
+         m->total_cols = size;
          m->pixel_width = new_pixel_size;
        }
       else




reply via email to

[Prev in Thread] Current Thread [Next in Thread]